@@ -79,7 +79,7 @@ def G(c_componente):#Guardar
   
   if dentro == False:
     global DatosList
-    DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
+    DatosList = DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
   
   #Renderizado Gris
   if c_componente[1] == None or dentro == False:
